@@ -1,5 +1,6 @@
+// $OpenLDAP$
 /*
- * Copyright 2000, OpenLDAP Foundation, All Rights Reserved.
+ * Copyright 2000-2012 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
  */
 
@@ -11,6 +12,8 @@
 #include "LDAPResult.h"
 #include "LDAPExtResult.h"
 
+using namespace std;
+
 LDAPExtResult::LDAPExtResult(const LDAPRequest* req, LDAPMessage* msg) :
         LDAPResult(req, msg){
     DEBUG(LDAP_DEBUG_CONSTRUCT,"LDAPExtResult::LDAPExtResult()" << endl);
