@@ -369,7 +369,24 @@ Entry*
 mdb_tool_entry_get( BackendDB *be, ID id )
 {
 	Entry *e = NULL;
+	int rc;
 
+	if ( !txn ) {
+		struct mdb_info *mdb = (struct mdb_info *) be->be_private;
+		rc = mdb_txn_begin( mdb->mi_dbenv, NULL,
+			(slapMode & SLAP_TOOL_READONLY) ? MDB_RDONLY : 0, &txn );
+		if ( rc )
+			return NULL;
+	}
+	if ( !cursor ) {
+		struct mdb_info *mdb = (struct mdb_info *) be->be_private;
+		rc = mdb_cursor_open( txn, mdb->mi_id2entry, &cursor );
+		if ( rc ) {
+			mdb_txn_abort( txn );
+			txn = NULL;
+			return NULL;
+		}
+	}
 	(void)mdb_tool_entry_get_int( be, id, &e );
 	return e;
 }
@@ -764,22 +781,6 @@ int mdb_tool_entry_reindex(
 		mi->mi_nattrs = i;
 	}
 
-	if ( slapMode & SLAP_TRUNCATE_MODE ) {
-		int i;
-		for ( i=0; i < mi->mi_nattrs; i++ ) {
-			rc = mdb_drop( txn, mi->mi_attrs[i]->ai_dbi, 0 );
-			if ( rc ) {
-				Debug( LDAP_DEBUG_ANY,
-					LDAP_XSTRING(mdb_tool_entry_reindex)
-					": (Truncate) mdb_drop(%s) failed: %s (%d)\n",
-					mi->mi_attrs[i]->ai_desc->ad_type->sat_cname.bv_val,
-					mdb_strerror(rc), rc );
-				return -1;
-			}
-		}
-		slapMode ^= SLAP_TRUNCATE_MODE;
-	}
-
 	e = mdb_tool_entry_get( be, id );
 
 	if( e == NULL ) {
@@ -801,6 +802,22 @@ int mdb_tool_entry_reindex(
 		}
 	}
 
+	if ( slapMode & SLAP_TRUNCATE_MODE ) {
+		int i;
+		for ( i=0; i < mi->mi_nattrs; i++ ) {
+			rc = mdb_drop( txi, mi->mi_attrs[i]->ai_dbi, 0 );
+			if ( rc ) {
+				Debug( LDAP_DEBUG_ANY,
+					LDAP_XSTRING(mdb_tool_entry_reindex)
+					": (Truncate) mdb_drop(%s) failed: %s (%d)\n",
+					mi->mi_attrs[i]->ai_desc->ad_type->sat_cname.bv_val,
+					mdb_strerror(rc), rc );
+				return -1;
+			}
+		}
+		slapMode ^= SLAP_TRUNCATE_MODE;
+	}
+
 	/*
 	 * just (re)add them for now
 	 * Use truncate mode to empty/reset index databases
